@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef CALENDARSUPPORT_PRINTING_CALPRINTER_H
 #define CALENDARSUPPORT_PRINTING_CALPRINTER_H
@@ -26,7 +10,7 @@
 #include "calendarsupport_export.h"
 #include "printplugin.h"
 
-#include <KComboBox>
+#include <QComboBox>
 #include <QDialog>
 #include <QPushButton>
 class QButtonGroup;
@@ -75,12 +59,10 @@ public Q_SLOTS:
     void updateConfig();
 
 private Q_SLOTS:
-    void doPrint(PrintPlugin *selectedStyle, ePrintOrientation dlgorientation,
-                 bool preview = false);
+    void doPrint(CalendarSupport::PrintPlugin *selectedStyle, CalendarSupport::CalPrinter::ePrintOrientation dlgorientation, bool preview = false);
 
 public:
-    void print(int type, const QDate &fd, const QDate &td,
-               const KCalCore::Incidence::List &selectedIncidences = KCalCore::Incidence::List(), bool preview = false);
+    void print(int type, const QDate &fd, const QDate &td, const KCalendarCore::Incidence::List &selectedIncidences = KCalendarCore::Incidence::List(), bool preview = false);
     Akonadi::ETMCalendar::Ptr calendar() const;
     KConfig *config() const;
 
@@ -91,15 +73,14 @@ private:
     Akonadi::ETMCalendar::Ptr mCalendar;
     QWidget *mParent = nullptr;
     KConfig *mConfig = nullptr;
-    bool mUniqItem;
+    const bool mUniqItem;
 };
 
 class CalPrintDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit CalPrintDialog(int initialPrintType, const PrintPlugin::List &plugins,
-                            QWidget *parent = nullptr, bool mUniqItem = false);
+    explicit CalPrintDialog(int initialPrintType, const PrintPlugin::List &plugins, QWidget *parent = nullptr, bool mUniqItem = false);
 
     ~CalPrintDialog() override;
 
@@ -108,16 +89,17 @@ public:
     CalPrinter::ePrintOrientation orientation() const;
 
 public Q_SLOTS:
-    void setPrintType(int);
+    void setPrintType(QAbstractButton *button);
     void setPreview(bool);
 
 private:
     void slotOk();
+    void changePrintType(int id);
     QButtonGroup *mTypeGroup = nullptr;
     QStackedWidget *mConfigArea = nullptr;
     QMap<int, PrintPlugin *> mPluginIDs;
     QString mPreviewText;
-    KComboBox *mOrientationSelection = nullptr;
+    QComboBox *mOrientationSelection = nullptr;
     QPushButton *mOkButton = nullptr;
     CalPrinter::ePrintOrientation mOrientation;
 };
